@@ -298,7 +298,7 @@ class GenomicPositionData:
         self.files_set: List[str] = files_set
         """List[str]: list of bam files analyzed."""
 
-        with open(self.config.promoter_file, "r") as f:
+        with open(self.config.promoter_file) as f:
             genome_base = f.readlines()
             genome_base_lines: List[str] = [s.rstrip("\n") for s in genome_base]
             self.genome_string: str = "".join(map(str, genome_base_lines))
@@ -432,14 +432,9 @@ class GenomicPositionData:
             filename (str): Filename to save to. Defaults to "output.xlsx".
         """
 
-        writer: pd.ExcelWriter = pd.ExcelWriter(
-            self.config.base_directory.joinpath(filename)
-        )
-
-        for name, each in self.quma_results.items():
-            each.values.to_excel(writer, sheet_name=name)
-
-        writer.save()
+        with pd.ExcelWriter(self.config.base_directory.joinpath(filename)) as writer:
+            for name, each in self.quma_results.items():
+                each.values.to_excel(writer, sheet_name=name)
 
     def save_pickle(self, filename: str) -> None:
         """Save GenomicPositionData object as a pickled file.
@@ -510,7 +505,7 @@ class GenomicPositionData:
         return df
 
     def _return_individual_data(self) -> pd.DataFrame:
-        """Return a dataframe for methylation values at each position for each cell line.
+        """Return a dataframe for methylation values at each pos for each cell line.
 
         Returns:
             pd.DataFrame: methylation values for each position in each cell line
