@@ -5,15 +5,20 @@
 import base64
 import unittest.mock as mock
 from pathlib import Path
+from typing import Any, Tuple
 
 import numpy as np
 
 # Required libraries for test data
 import pandas as pd
 import pytest
+from _pytest.monkeypatch import MonkeyPatch
+from pytest import TempPathFactory
+from pytest_mock.plugin import MockerFixture
 
 # Module to test
 from pyllelic import pyllelic
+from pyllelic.config import Config
 
 from .inputs import (
     EXPECTED_ALLELIC_DATA,
@@ -36,10 +41,14 @@ from .inputs import (
 
 # import os
 
+PositionDataTuple = Tuple[Path, pyllelic.GenomicPositionData]
+
 
 # Helper methods
 @pytest.fixture(scope="session")
-def set_up_genomic_position_data(tmp_path_factory):
+def set_up_genomic_position_data(
+    tmp_path_factory: TempPathFactory,
+) -> PositionDataTuple:
     tmp_path = tmp_path_factory.mktemp("data")
     p, _ = setup_bam_files(tmp_path)
     config = setup_config(p)
@@ -51,26 +60,31 @@ def set_up_genomic_position_data(tmp_path_factory):
 
 
 @pytest.fixture(autouse=True)
-def mock_pool_apply_async(monkeypatch):
+def mock_pool_apply_async(monkeypatch: MonkeyPatch) -> None:
     monkeypatch.setattr("multiprocessing.pool.Pool.apply_async", _mock_apply_async)
 
 
-def _mock_apply_async(
-    self, func, args=(), kwds=None, callback=None, error_callback=None
-):
-    return MockPoolApplyResult(func, args)
-
-
 class MockPoolApplyResult:
-    def __init__(self, func, args):
+    def __init__(self, func: Any, args: Any) -> None:
         self._func = func
         self._args = args
 
-    def get(self, timeout=0):
+    def get(self, timeout: int = 0) -> Any:
         return self._func(*self._args)
 
 
-def setup_bam_files(tmp_path):
+def _mock_apply_async(
+    self: Any,
+    func: Any,
+    args: Any = (),
+    kwds: Any = None,
+    callback: Any = None,
+    error_callback: Any = None,
+) -> MockPoolApplyResult:
+    return MockPoolApplyResult(func, args)
+
+
+def setup_bam_files(tmp_path: Path) -> Tuple[Path, Path]:
     d = tmp_path / "test"
     d.mkdir()
     fn_bam = "fh_test_tissue.bam"
@@ -82,7 +96,7 @@ def setup_bam_files(tmp_path):
     return tmp_path, filepath_bam
 
 
-def setup_config(my_path):
+def setup_config(my_path: Path) -> Config:
     d = my_path
     prom_file = d / "test.txt"
     prom_file.write_text(TEST_PROM_FILE)
@@ -91,8 +105,8 @@ def setup_config(my_path):
     TEST_CHR = "5"
     TEST_OFFSET = 1293000
     config = pyllelic.configure(
-        base_path=my_path,
-        prom_file=prom_file,
+        base_path=str(my_path),
+        prom_file=str(prom_file),
         prom_start=TEST_START,
         prom_end=TEST_END,
         chrom=TEST_CHR,
@@ -113,7 +127,7 @@ TEST_QUMA_RESULT = (
 
 
 # Tests
-def test_configure():
+def test_configure() -> None:
     """Test setting environment variables with mock object."""
     TEST_BASE_PATH = Path().cwd()
     TEST_PROM_FILE = TEST_BASE_PATH / "test.txt"
@@ -123,22 +137,22 @@ def test_configure():
     TEST_OFFSET = 0
     EXPECTED_RESULTS = TEST_BASE_PATH / "results"
     config = pyllelic.configure(
-        base_path=TEST_BASE_PATH,
-        prom_file=TEST_PROM_FILE,
-        prom_start=TEST_START,
-        prom_end=TEST_END,
+        base_path=str(TEST_BASE_PATH),
+        prom_file=str(TEST_PROM_FILE),
+        prom_start=int(TEST_START),
+        prom_end=int(TEST_END),
         chrom=TEST_CHR,
         offset=TEST_OFFSET,
     )
 
     assert TEST_BASE_PATH == config.base_directory
     assert TEST_PROM_FILE == config.promoter_file
-    assert TEST_START == config.promoter_start
-    assert TEST_END == config.promoter_end
+    assert int(TEST_START) == config.promoter_start
+    assert int(TEST_END) == config.promoter_end
     assert EXPECTED_RESULTS == config.results_directory
 
 
-def test_make_list_of_bam_files(tmp_path):
+def test_make_list_of_bam_files(tmp_path: Path) -> None:
     config = setup_config(tmp_path)
     TEST_LIST = [
         Path("bad1.txt"),
@@ -147,14 +161,16 @@ def test_make_list_of_bam_files(tmp_path):
         Path("fh_good2_tissue.bam"),
     ]
     EXPECTED = ["fh_good1_tissue.bam", "fh_good2_tissue.bam"]
-    with mock.patch.object(pyllelic.Path, "iterdir") as mock_iterdir:
+    with mock.patch.object(
+        pyllelic.Path, "iterdir"  # type:ignore[attr-defined]
+    ) as mock_iterdir:
         mock_iterdir.return_value = TEST_LIST
         actual = pyllelic.make_list_of_bam_files(config)
 
     assert EXPECTED == actual
 
 
-def test_pyllelic(tmp_path_factory):
+def test_pyllelic(tmp_path_factory: TempPathFactory) -> None:
     tmp_path = tmp_path_factory.mktemp("data")
     p, _ = setup_bam_files(tmp_path)
     config = setup_config(p)
@@ -175,7 +191,7 @@ class Test_BamOutput:
     # pylint: disable=no-self-use
 
     @pytest.fixture()
-    def set_up_bam_output(self, tmp_path):
+    def set_up_bam_output(self, tmp_path: Path) -> pyllelic.BamOutput:
         p, fp_bam = setup_bam_files(tmp_path)
         config = setup_config(p)
         return pyllelic.BamOutput(
@@ -184,7 +200,7 @@ class Test_BamOutput:
             config=config,
         )
 
-    def test_init(self, tmp_path, set_up_bam_output):
+    def test_init(self, tmp_path: Path, set_up_bam_output: pyllelic.BamOutput) -> None:
         bam_output = set_up_bam_output
 
         assert bam_output.name == str(tmp_path / "test" / "fh_test_tissue.bam")
@@ -192,38 +208,42 @@ class Test_BamOutput:
         assert bam_output.positions == EXPECTED_BAM_OUTPUT_POSITIONS
         assert bam_output.genome_values == EXPECTED_BAM_OUTPUT_GENOME_VALUES
 
-    def test_run_sam_and_extract_df(self, set_up_bam_output):
+    def test_run_sam_and_extract_df(
+        self, set_up_bam_output: pyllelic.BamOutput
+    ) -> None:
         bam_output = set_up_bam_output
         actual_positions = bam_output._run_sam_and_extract_df(Path(bam_output.name))
         assert actual_positions == EXPECTED_BAM_OUTPUT_POSITIONS
 
-    def test_write_bam_output(self, set_up_bam_output):
+    def test_write_bam_output(self, set_up_bam_output: pyllelic.BamOutput) -> None:
         bam_output = set_up_bam_output
         bam_output._write_bam_output(bam_output.positions, EXPECTED_STACKED_BAM)
         assert bam_output.values == EXPECTED_WRITE_DF_OUTPUT
 
-    def test__genome_range(self, set_up_bam_output):
+    def test__genome_range(self, set_up_bam_output: pyllelic.BamOutput) -> None:
         bam_output = set_up_bam_output
         gen_str = "ATGCATGCATGCATGCATGCATGCATGCATGCATGCATGCATGCATGC"
-        result = bam_output._genome_range(position=8, genome_string=gen_str, offset=2)
+        result = bam_output._genome_range(position="8", genome_string=gen_str, offset=2)
         assert result == gen_str[6:36]
         assert isinstance(result, str)
 
-    def test__genome_range_no_offset(self, set_up_bam_output):
+    def test__genome_range_no_offset(
+        self, set_up_bam_output: pyllelic.BamOutput
+    ) -> None:
         bam_output = set_up_bam_output
         gen_str = "ATGCATGCATGCATGCATGCATGCATGCATGCATGCATGCATGCATGC"
         bam_output._config.offset = 2
-        result = bam_output._genome_range(position=8, genome_string=gen_str)
+        result = bam_output._genome_range(position="8", genome_string=gen_str)
         assert result == gen_str[6:36]
         assert isinstance(result, str)
 
-    def test__genome_range_invalid(self, set_up_bam_output):
+    def test__genome_range_invalid(self, set_up_bam_output: pyllelic.BamOutput) -> None:
         bam_output = set_up_bam_output
         gen_str = ""
         with pytest.raises(ValueError):
-            _ = bam_output._genome_range(position=2, genome_string=gen_str, offset=40)
+            _ = bam_output._genome_range(position="2", genome_string=gen_str, offset=40)
 
-    def test_genome_parsing(self, set_up_bam_output):
+    def test_genome_parsing(self, set_up_bam_output: pyllelic.BamOutput) -> None:
         pass
 
 
@@ -233,13 +253,13 @@ class Test_QumaOutput:
     # pylint: disable=no-self-use
 
     @pytest.fixture()
-    def set_up_quma_output(self):
+    def set_up_quma_output(self) -> pyllelic.QumaResult:
 
         INPUT_GENOMIC_FILE = ["CGGCGTAGGTAGGTTCGTACGAAGTCGTA"]
 
         return pyllelic.QumaResult(INPUT_READ_FILE, INPUT_GENOMIC_FILE, ["1293588"])
 
-    def test_init(self, set_up_quma_output):
+    def test_init(self, set_up_quma_output: pyllelic.QumaResult) -> None:
         quma_output = set_up_quma_output
 
         EXPECTED_QUMA_VALUES = pd.DataFrame.from_dict(
@@ -257,7 +277,7 @@ class Test_QumaOutput:
 
         pd.testing.assert_frame_equal(quma_output.values, EXPECTED_QUMA_VALUES)
 
-    def test_process_raw_quma(self, set_up_quma_output):
+    def test_process_raw_quma(self, set_up_quma_output: pyllelic.QumaResult) -> None:
         quma_output = set_up_quma_output
 
         quma_reference = quma_output.quma_output[0].data
@@ -266,7 +286,9 @@ class Test_QumaOutput:
         actual = quma_output._process_raw_quma(quma_reference)
         assert EXPECTED == actual
 
-    def test_process_raw_quma_below_min_alignment(self, set_up_quma_output):
+    def test_process_raw_quma_below_min_alignment(
+        self, set_up_quma_output: pyllelic.QumaResult
+    ) -> None:
         quma_output = set_up_quma_output
 
         quma_reference = quma_output.quma_output[0].data
@@ -276,7 +298,7 @@ class Test_QumaOutput:
         actual = quma_output._process_raw_quma(quma_reference)
         assert EXPECTED == actual
 
-    def test__pool_processing(self, set_up_quma_output):
+    def test__pool_processing(self, set_up_quma_output: pyllelic.QumaResult) -> None:
         quma_output = set_up_quma_output
 
         EXPECTED_RESULTS = pd.DataFrame.from_dict(
@@ -297,12 +319,14 @@ class Test_QumaOutput:
         pd.testing.assert_frame_equal(actual, EXPECTED_RESULTS)
 
     @mock.patch("pyllelic.pyllelic.signal.signal")
-    def test__init_worker(self, mock_signal, set_up_quma_output):
+    def test__init_worker(
+        self, mock_signal: mock.Mock, set_up_quma_output: pyllelic.QumaResult
+    ) -> None:
         quma_output = set_up_quma_output
         quma_output._init_worker()
         mock_signal.assert_called_once()
 
-    def test__thread_worker(self, set_up_quma_output):
+    def test__thread_worker(self, set_up_quma_output: pyllelic.QumaResult) -> None:
         quma_output = set_up_quma_output
         TEST_READ_NAME = "1295094"
         TEST_GSEQ = ">genome\nATCGTAGTCGA"
@@ -315,7 +339,7 @@ class Test_QumaOutput:
         pd.testing.assert_frame_equal(actual[0], EXPECTED)
         assert actual[1].values == EXPECTED_QUMA_VALUES
 
-    def test_access_quma(self, set_up_quma_output):
+    def test_access_quma(self, set_up_quma_output: pyllelic.QumaResult) -> None:
         quma_output = set_up_quma_output
         TEST_GSEQ = ">genome\nATCGTAGTCGA"
         TEST_QSEQ = ">query1\nATCGTAGTCGA\n>query2\nATCGATAGCATT"
@@ -329,7 +353,7 @@ class Test_GenomicPositionData:
 
     # pylint: disable=no-self-use
 
-    def test_init(self, set_up_genomic_position_data):
+    def test_init(self, set_up_genomic_position_data: PositionDataTuple) -> None:
         p, genomic_position_data = set_up_genomic_position_data
 
         assert genomic_position_data.positions == EXPECTED_BAM_INDIVIDUAL_POSITIONS
@@ -342,7 +366,9 @@ class Test_GenomicPositionData:
 
     #     mocker.assert_called()
 
-    def test_process_means(self, set_up_genomic_position_data):
+    def test_process_means(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
 
         intermediate = EXPECTED_MEANS
@@ -351,7 +377,9 @@ class Test_GenomicPositionData:
         np.array_equal(genomic_position_data.means.values, expected.values)
         # pd.testing.assert_frame_equal(genomic_position_data.means, expected)
 
-    def test_histogram(self, set_up_genomic_position_data, mocker):
+    def test_histogram(
+        self, set_up_genomic_position_data: PositionDataTuple, mocker: MockerFixture
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         mocked_go = mocker.patch("pyllelic.visualization.go")
         TEST_POSITION = genomic_position_data.positions[0]
@@ -363,7 +391,9 @@ class Test_GenomicPositionData:
         mocked_go.Figure.assert_called()
         mocked_go.Histogram.assert_called()
 
-    def test_histogram_mpl(self, set_up_genomic_position_data, mocker):
+    def test_histogram_mpl(
+        self, set_up_genomic_position_data: PositionDataTuple, mocker: MockerFixture
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         mocked_mpl = mocker.patch("pyllelic.visualization.sns")
         TEST_POSITION = genomic_position_data.positions[0]
@@ -375,7 +405,9 @@ class Test_GenomicPositionData:
         mocked_mpl.histplot.assert_called_once()
         genomic_position_data.config.viz_backend = "plotly"
 
-    def test_histogram_error(self, set_up_genomic_position_data):
+    def test_histogram_error(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         TEST_POSITION = genomic_position_data.positions[0]
         TEST_CELL_LINE = genomic_position_data.means.index[0]
@@ -385,7 +417,9 @@ class Test_GenomicPositionData:
             genomic_position_data.histogram(TEST_CELL_LINE, TEST_POSITION)
         genomic_position_data.config.viz_backend = "plotly"
 
-    def test_heatmap(self, set_up_genomic_position_data, mocker):
+    def test_heatmap(
+        self, set_up_genomic_position_data: PositionDataTuple, mocker: MockerFixture
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         mocked_go = mocker.patch("pyllelic.visualization.go")
 
@@ -395,7 +429,9 @@ class Test_GenomicPositionData:
         mocked_go.Figure.assert_called()
         mocked_go.Heatmap.assert_called()
 
-    def test_heatmap_mpl(self, set_up_genomic_position_data, mocker):
+    def test_heatmap_mpl(
+        self, set_up_genomic_position_data: PositionDataTuple, mocker: MockerFixture
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         mocked_mpl = mocker.patch("pyllelic.visualization.sns")
 
@@ -405,7 +441,9 @@ class Test_GenomicPositionData:
         mocked_mpl.heatmap.assert_called_once()
         genomic_position_data.config.viz_backend = "plotly"
 
-    def test_heatmap_error(self, set_up_genomic_position_data):
+    def test_heatmap_error(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
 
         with pytest.raises(ValueError):
@@ -413,7 +451,9 @@ class Test_GenomicPositionData:
             genomic_position_data.heatmap(min_values=1)
         genomic_position_data.config.viz_backend = "plotly"
 
-    def test_heatmap_cell_lines(self, set_up_genomic_position_data, mocker):
+    def test_heatmap_cell_lines(
+        self, set_up_genomic_position_data: PositionDataTuple, mocker: MockerFixture
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         mocked_go = mocker.patch("pyllelic.visualization.go")
 
@@ -423,7 +463,9 @@ class Test_GenomicPositionData:
         mocked_go.Figure.assert_called_once()
         mocked_go.Heatmap.assert_called_once()
 
-    def test_heatmap_modes(self, set_up_genomic_position_data, mocker):
+    def test_heatmap_modes(
+        self, set_up_genomic_position_data: PositionDataTuple, mocker: MockerFixture
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         mocked_go = mocker.patch("pyllelic.visualization.go")
 
@@ -432,7 +474,9 @@ class Test_GenomicPositionData:
         mocked_go.Figure.assert_called_once()
         mocked_go.Heatmap.assert_called_once()
 
-    def test_heatmap_diffs(self, set_up_genomic_position_data, mocker):
+    def test_heatmap_diffs(
+        self, set_up_genomic_position_data: PositionDataTuple, mocker: MockerFixture
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         mocked_go = mocker.patch("pyllelic.visualization.go")
 
@@ -441,13 +485,17 @@ class Test_GenomicPositionData:
         mocked_go.Figure.assert_called_once()
         mocked_go.Heatmap.assert_called_once()
 
-    def test_heatmap_invalid(self, set_up_genomic_position_data):
+    def test_heatmap_invalid(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
 
         with pytest.raises(ValueError):
             genomic_position_data.heatmap(min_values=1, data_type="FAKE")
 
-    def test_reads_graph(self, set_up_genomic_position_data, mocker):
+    def test_reads_graph(
+        self, set_up_genomic_position_data: PositionDataTuple, mocker: MockerFixture
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         mocked_px = mocker.patch("pyllelic.visualization.px")
         mocked_sp = mocker.patch("pyllelic.visualization.sp")
@@ -464,7 +512,9 @@ class Test_GenomicPositionData:
         mocked_df_plot.assert_called()
         mocked_mpl.subplots.assert_called()
 
-    def test_reads_graph_cell_lines(self, set_up_genomic_position_data, mocker):
+    def test_reads_graph_cell_lines(
+        self, set_up_genomic_position_data: PositionDataTuple, mocker: MockerFixture
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         mocked_px = mocker.patch("pyllelic.visualization.px")
         mocked_sp = mocker.patch("pyllelic.visualization.sp")
@@ -475,13 +525,17 @@ class Test_GenomicPositionData:
         mocked_px.bar.assert_called()
         mocked_sp.make_subplots.assert_called_once()
 
-    def test_reads_graph_invalid(self, set_up_genomic_position_data):
+    def test_reads_graph_invalid(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
 
         with pytest.raises(ValueError):
             genomic_position_data.reads_graph(backend="FAKE")
 
-    def test_summarize_allelelic_data(self, set_up_genomic_position_data):
+    def test_summarize_allelelic_data(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
 
         with np.testing.suppress_warnings() as sup:  # ignore degrees of freedom warning
@@ -502,7 +556,7 @@ class Test_GenomicPositionData:
     #     mocked_go = mocker.patch("pyllelic.visualization.go")
     #     mocked_mpl = mocker.patch("pyllelic.visualization.pd.DataFrame.plot")
 
-    #     with np.testing.suppress_warnings() as sup:  # ignore degrees of freedom warning
+    #     with np.testing.suppress_warnings() as sup:  # ignore deg of freedom warning
     #         sup.filter(RuntimeWarning, "Degrees of freedom")
     #         sup.filter(module=np.ma.core)
     #         genomic_position_data.sig_methylation_differences()
@@ -513,7 +567,9 @@ class Test_GenomicPositionData:
     #         mocked_go.Bar.assert_called()
     #         mocked_mpl.assert_called_once()
 
-    def test_sig_methylation_differences_invalid(self, set_up_genomic_position_data):
+    def test_sig_methylation_differences_invalid(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
 
         with np.testing.suppress_warnings() as sup:  # ignore degrees of freedom warning
@@ -522,7 +578,9 @@ class Test_GenomicPositionData:
             with pytest.raises(ValueError):
                 genomic_position_data.sig_methylation_differences(backend="FAKE")
 
-    def test_anderson_darling_test_with_values(self, set_up_genomic_position_data):
+    def test_anderson_darling_test_with_values(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         TEST_LIST = pd.Series([1.0, 1.0, 1.0, (2 / 3), (2 / 3), (2 / 3)])
         actual = genomic_position_data._anderson_darling_test(TEST_LIST)
@@ -532,10 +590,12 @@ class Test_GenomicPositionData:
             np.array([0.592, 0.675, 0.809, 0.944, 1.123]),
         )
         assert EXPECTED[0] == actual[0]
-        np.testing.assert_equal(EXPECTED[1], actual[1])
+        np.testing.assert_almost_equal(EXPECTED[1], actual[1])  # type:ignore
         assert (EXPECTED[2] == actual[2]).all()
 
-    def test_anderson_darling_test_with_bad(self, set_up_genomic_position_data):
+    def test_anderson_darling_test_with_bad(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         TEST_LIST = [np.nan]
         actual = genomic_position_data._anderson_darling_test(TEST_LIST)
@@ -544,7 +604,9 @@ class Test_GenomicPositionData:
         np.testing.assert_equal(EXPECTED[1], actual[1])
         assert EXPECTED[2] == actual[2]
 
-    def test_generate_ad_stats(self, set_up_genomic_position_data):
+    def test_generate_ad_stats(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         TEST_DF = EXPECTED_INTERMEDIATE_INDIVIDUAL_DATA
         EXPECTED = pd.DataFrame.from_dict(
@@ -585,7 +647,9 @@ class Test_GenomicPositionData:
         EXPECTED_TEST2_1 = EXPECTED.loc["TEST2", "1"]
         np.testing.assert_equal(EXPECTED_TEST2_1, actual.loc["TEST2", "1"])
 
-    def test_write_means_modes_diffs(self, mocker, set_up_genomic_position_data):
+    def test_write_means_modes_diffs(
+        self, mocker: MockerFixture, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         TEST_FILENAME = "output"
         mocker.patch.object(genomic_position_data.means, "to_excel")
@@ -598,7 +662,9 @@ class Test_GenomicPositionData:
         genomic_position_data.modes.to_excel.assert_called()
         genomic_position_data.diffs.to_excel.assert_called()
 
-    def test_save(self, mocker, set_up_genomic_position_data):
+    def test_save(
+        self, mocker: MockerFixture, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         TEST_FILENAME = "output"
         # mocked_excel_writer = mocker.patch("pyllelic.pyllelic.pd.ExcelWriter")
@@ -608,7 +674,9 @@ class Test_GenomicPositionData:
         mocked_dataframe.assert_called()
         # mocked_excel_writer.ExcelWriter.assert_called()
 
-    def test_save_pickle(self, mocker, set_up_genomic_position_data):
+    def test_save_pickle(
+        self, mocker: MockerFixture, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
         mocked_pickle = mocker.patch("pyllelic.pyllelic.pickle")
 
@@ -617,20 +685,22 @@ class Test_GenomicPositionData:
 
         mocked_pickle.dump.assert_called()
 
-    def test_from_pickle(self, mocker):
+    def test_from_pickle(self, mocker: MockerFixture) -> None:
         mocked_pickle = mocker.patch("pyllelic.pyllelic.pickle")
 
         TEST_FILENAME = "example.pickle"
         _ = pyllelic.GenomicPositionData.from_pickle(TEST_FILENAME)
         mocked_pickle.load.assert_called()
 
-    def test__truncate_diffs(self):
+    def test__truncate_diffs(self) -> None:
         TEST_DIFFS = EXPECTED_INTERMEDIATE_DIFFS.astype("object")
         EXPECTED_TRUNCATED_DIFF = TEST_DIFFS.dropna(how="all")
         actual = pyllelic.GenomicPositionData._truncate_diffs(TEST_DIFFS)
         pd.testing.assert_frame_equal(actual, EXPECTED_TRUNCATED_DIFF)
 
-    def test_return_individual_positions(self, set_up_genomic_position_data):
+    def test_return_individual_positions(
+        self, set_up_genomic_position_data: PositionDataTuple
+    ) -> None:
         _, genomic_position_data = set_up_genomic_position_data
 
         actual = genomic_position_data._return_individual_positions("test")
